src/c/so3_sampling.h Source File

# so3_sampling.h

Go to the documentation of this file.

    00001 // S03 package to perform Wigner transform on the rotation group SO(3)
    00002 // Copyright (C) 2013 Martin Büttner and Jason McEwen
    00003 // See LICENSE.txt for license details
    00004
    00005 #ifndef SO3_SAMPLING
    00006 #define SO3_SAMPLING
    00007
    00008 #include "so3_types.h"
    00009
    00010 complex double so3_sampling_weight(const so3_parameters_t *parameters, int p);
    00011
    00012 int so3_sampling_f_size(const so3_parameters_t *parameters);
    00013 int so3_sampling_n(const so3_parameters_t *parameters);
    00014 int so3_sampling_nalpha(const so3_parameters_t *parameters);
    00015 int so3_sampling_nbeta(const so3_parameters_t *parameters);
    00016 int so3_sampling_ngamma(const so3_parameters_t *parameters);
    00017
    00018 double so3_sampling_a2alpha(int a, const so3_parameters_t *parameters);
    00019 double so3_sampling_b2beta(int b, const so3_parameters_t *parameters);
    00020 double so3_sampling_g2gamma(int g, const so3_parameters_t *parameters);
    00021
    00022 // Note, if this is compiled using C99-standard then the "extern" belongs in the
    00023 // .c file instead.
    00024 extern inline int so3_sampling_flmn_size(const so3_parameters_t *parameters);
    00025 extern inline void so3_sampling_elmn2ind(int *ind, int el, int m, int n, const so3_parameters_t *parameters);
    00026 extern inline void so3_sampling_ind2elmn(int *el, int *m, int *n, int ind, const so3_parameters_t *parameters);
    00027 extern inline void so3_sampling_elmn2ind_real(int *ind, int el, int m, int n, const so3_parameters_t *parameters);
    00028 extern inline void so3_sampling_ind2elmn_real(int *el, int *m, int *n, int ind, const so3_parameters_t *parameters);
    00029
    00030 #endif